@@ -1,5 +1,5 @@
 package Mooish::AttributeBuilder;
-$Mooish::AttributeBuilder::VERSION = '1.001';
+$Mooish::AttributeBuilder::VERSION = '1.002';
 use v5.10;
 use strict;
 use warnings;
@@ -7,6 +7,13 @@ use warnings;
 use Carp qw(croak);
 use Scalar::Util qw(blessed);
 
+my $set_subname;
+BEGIN {
+	if (eval { require Sub::Util } && Sub::Util->VERSION >= 1.40) {
+		$set_subname = \&Sub::Util::set_subname;
+	}
+}
+
 ### These subs can be extended in subclasses
 
 # List of available attribute types. May be extended if a custom function will
@@ -67,15 +74,20 @@ sub method_prefixes
 sub import
 {
 	my ($self, $caller) = (shift, scalar caller);
+	state $export_cache = {};
 
-	my %flags = map { $_ => 1 } @_;
+	my %flags = map { $_ => $_ } @_;
 
+	my $cache_key = $self . ($flags{-standard} || '');
 	foreach my $type (keys %{$self->attribute_types}) {
-		my $function = sub {
+		my $function = $export_cache->{$cache_key . $type} //= sub {
 			my ($name, %args) = @_;
 			return $self->expand_shortcuts($flags{-standard}, $type => $name, %args);
 		};
 
+		$set_subname->("${self}::${type}", $function)
+			if $set_subname;
+
 		NO_STRICT: {
 			no strict 'refs';
 			*{"${caller}::${type}"} = $function;
